@@ -5,10 +5,10 @@
 
 
 void F77_SUB(wu)(double *gt, double *tol, int *maxit,
-		  int *n, int *q, int *k, int *conv,
+		  int *n, int *q, double *k, int *conv,
 		  double *obj, double *lam);
 		 
-void F77_SUB(lamcuep)(double *gt, int *n, int *q, int *k,
+void F77_SUB(lamcuep)(double *gt, int *n, int *q, double *k,
 		       int *maxit, int *conv, double *lam,
 		       double *pt, double *obj);
 
